# Portmin

**Portmin** is a simple wrapper around FORTRAN **PORT** optimization routines. It was developed as a side-task for our **SEMOpt** package.

## Author

* **Mescheryakov Georgy Andreyevich** - [Herrberg](https://bitbucket.org/herrberg) - undegraduate student, SPbSTU

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details.